@@ -3,7 +3,7 @@ package App::CekBpom;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-09-02'; # DATE
 our $DIST = 'App-CekBpom'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -117,7 +117,9 @@ sub cek_bpom {
                            <td[^>]*>(?P<nama>[^<]+)<div>Merk: (?P<merk>[^<]+)<br>Kemasan: (?P<kemasan>[^<]+)</div></td>
                            <td[^>]*>(?P<pendaftar>[^<]+)<div>(?P<kota_pendaftar>[^<]+)</div></td>
                        !sgx) {
-            push @rows, {%+};
+            my $row = {%+};
+            for (qw/kemasan/) { $row->{$_} =~ s/\R+//g }
+            push @rows, $row;
         }
         last;
     }
@@ -148,7 +150,7 @@ App::CekBpom - Check BPOM products via the command-line (CLI interface for cekbp
 
 =head1 VERSION
 
-This document describes version 0.002 of App::CekBpom (from Perl distribution App-CekBpom), released on 2020-09-02.
+This document describes version 0.003 of App::CekBpom (from Perl distribution App-CekBpom), released on 2020-09-02.
 
 =head1 DESCRIPTION
 
